<?php
/**
 * Edusion functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Edusion
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function edusion_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Edusion, use a find and replace
		* to change 'edusion' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'edusion', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'edusion_testi', 200,200, true );
	add_image_size( 'edusion_blog', 370,260, true );
	add_image_size( 'edusion_course', 420,280, true );
	add_image_size( 'edusion_course_related', 80,82, true );
	add_image_size( 'edusion_event', 370,270, true );
	add_image_size( 'edusion_event_signle', 1200,800, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'edusion' ),
			'menu-2' => esc_html__( 'Footer', 'edusion' ),
		)
	);

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );
	
	// Add support for editor styles.
	add_theme_support( 'editor-styles' );
	
	/*
	 * Set woocommerce support  
	 * 
	 */
	add_theme_support( 'woocommerce' );	
	
	
	add_theme_support( "wp-block-styles" );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "align-wide" );
	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'edusion_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
	

	
}
add_action( 'after_setup_theme', 'edusion_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function edusion_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'edusion_content_width', 640 );
}
add_action( 'after_setup_theme', 'edusion_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function edusion_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'edusion' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'edusion' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);	
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Left Footer', 'edusion' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'edusion' ),
			'before_widget' => '<section id="%1$s" class="%2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);	
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'edusion' ),
			'id'            => 'sidebar-3',
			'description'   => esc_html__( 'Add widgets here.', 'edusion' ),
			'before_widget' => '<div id="%1$s" class="col-lg-4 col-md-4 col-sm-6 col-12 %2$s"> <div class="single_footer">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>',
		)
	);
	
}
add_action( 'widgets_init', 'edusion_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function edusion_scripts() {
	
	// Add CSS Files

	wp_enqueue_style('mulish-font' , '//fonts.googleapis.com/css2?family=Mulish:wght@300;400;500;600;700;800&display=swap');
	wp_enqueue_style('bootstrap' , get_template_directory_uri(). '/assets/bootstrap/css/bootstrap.min.css');
	wp_enqueue_style('font-awesome' , get_template_directory_uri(). '/assets/fonts/font-awesome.min.css');
	wp_enqueue_style('themify-icons' , get_template_directory_uri(). '/assets/fonts/themify-icons.css');
	wp_enqueue_style('owl-carousel' , get_template_directory_uri(). '/assets/owlcarousel/css/owl.carousel.css');
	wp_enqueue_style('owl-theme' , get_template_directory_uri(). '/assets/owlcarousel/css/owl.theme.css');
	wp_enqueue_style('slicknav' , get_template_directory_uri(). '/assets/css/slicknav.css');
	wp_enqueue_style('magnific-popup' , get_template_directory_uri(). '/assets/css/magnific-popup.css');
	wp_enqueue_style('YouTubePopUp' , get_template_directory_uri(). '/assets/css/YouTubePopUp.css');
	wp_enqueue_style('animate' , get_template_directory_uri(). '/assets/css/animate.css');
	wp_enqueue_style('edusion-main-style' , get_template_directory_uri(). '/assets/css/style.css');
	wp_enqueue_style('edusion-responsive' , get_template_directory_uri(). '/assets/css/responsive.css');
	
	wp_enqueue_style( 'edusion-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'edusion-style', 'rtl', 'replace' );
	add_editor_style( 'custom-editor-style.css' );
	
	// Load JS Files
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/bootstrap/js/bootstrap.min.js', array('jquery'), '985', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/owlcarousel/js/owl.carousel.min.js', array('jquery'), '985', true );
	wp_enqueue_script( 'slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array('jquery'), '985', true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), '985', true );
	wp_enqueue_script( 'YouTubePopUp.jquery', get_template_directory_uri() . '/assets/js/YouTubePopUp.jquery.js', array('jquery'), '985', true );
	wp_enqueue_script( 'mixitup', get_template_directory_uri() . '/assets/js/jquery.mixitup.js', array('jquery'), '985', true );
	wp_enqueue_script( 'scrolltopcontrol', get_template_directory_uri() . '/assets/js/scrolltopcontrol.js', array('jquery'), '985', true );
	wp_enqueue_script( 'purecounter_vanilla', get_template_directory_uri() . '/assets/js/purecounter_vanilla.js', array('jquery'), '985', true );
	wp_enqueue_script( 'wow', get_template_directory_uri() . '/assets/js/wow.min.js', array('jquery'), '985', true );
	wp_enqueue_script( 'edusion-scripts', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), '985', true );
	
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'edusion_scripts' );

// Main_menu
function edusion_main_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-1',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => ' ',
		'fallback_cb'       => 'edusion_navwalker::fallback',
		
		)
	); 	
}

// Footer_menu
function edusion_footer_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'menu-2',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => ' ',
		'fallback_cb'       => 'edusion_navwalker::fallback',
		
		)
	); 	
}

// Edusion wp kses
function edusion_wp_kses($val){
	return wp_kses($val, array(
	
	'p' => array(),
	'span' => array('class' => array(),'id' => array()),
	'div' => array(),
	'strong' => array(),
	'em' => array(),
	'u' => array(),	
	'b' => array(),
	'br' => array(),
	'h1' => array(),
	'h2' => array(),
	'h3' => array(),
	'h4' => array(),
	'h5' => array(),
	'h6' => array(),
	'i'=> array('class' => array(),'id' => array()),
	'div'=> array('class' => array(),'id' => array()),
	'ul'=> array('class' => array(),'id' => array()),
	'li'=> array('class' => array(),'id' => array()),
	'a'=> array('href' => array(),'target' => array()),
	'iframe'=> array('src' => array(),'height' => array(),'width' => array()),
	
	), '');
}

// modify search widget
function edusion_my_search_form( $form ) {
	$form = '
			
		<form method="get" class="search-form" action="' . esc_url(home_url( '/' )) . '" >
			<input type="text" value="' . esc_attr(get_search_query()) . '" name="s" id="s" class="form-control" placeholder="' . esc_attr__('Search' , 'edusion') .'">
			<button type="submit" class="search-submit"><i class="fa fa-search"></i></button>
		</form>
			
		
        ';
	return $form;
}
add_filter( 'get_search_form', 'edusion_my_search_form' );


// comment list modify

function edusion_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>

<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

	<div class="comment-box">
		<div class="comment-avatar">
			<?php echo get_avatar( $comment, 95 ); ?>
		</div>
		<div class="comment-info">
			<h5><?php comment_author_link() ?></h5>
			<span><?php echo esc_html(get_comment_date('F j, Y')); ?></span>
			<?php if ($comment->comment_approved == '0') : ?>
			<p><em><?php esc_html_e('Your comment is awaiting moderation.','edusion'); ?></em></p>
			<?php endif; ?>			
			<?php comment_text(); ?>
			<div class="reply-link"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></div>			
		</div>
	</div>
								
</li>


<?php } 

// comment box title change
add_filter( 'comment_form_defaults', 'edusion_remove_comment_form_allowed_tags' );
function edusion_remove_comment_form_allowed_tags( $defaults ) {

	$defaults['comment_notes_after'] = '';
	$defaults['comment_notes_before'] = '';
	return $defaults;

}

function edusion_comment_reform ($arg) {

$arg['title_reply'] = esc_html__('Write your comment Here','edusion');
$arg['comment_field'] = '<div class="row"><div class="form-group col-lg-12"><textarea id="comment" class="comment_field form-control" name="comment" cols="30" rows="6" placeholder="'. esc_attr__("Comment", "edusion").'" aria-required="true"></textarea></div></div>';


return $arg;

}
add_filter('comment_form_defaults','edusion_comment_reform');

// comment form modify

function edusion_modify_comment_form_fields($fields){
	$commenter = wp_get_current_commenter();
	$req	   = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row"><div class="form-group col-lg-6"><input type="text" name="author" id="author" value="'. esc_attr( $commenter['comment_author'] ) .'" placeholder="'. esc_attr__("Your Name *", "edusion").'" size="22" tabindex="1"'. ( $req ? 'aria-required="true"' : '' ).' class="input-name form-control" /></div>';

	$fields['email'] = '<div class="form-group col-lg-6"><input type="text" name="email" id="email" value="'. esc_attr( $commenter['comment_author_email'] ) .'" placeholder="'.esc_attr__("Your Email *", "edusion").'" size="22" tabindex="2"'. ( $req ? 'aria-required="true"' : '' ).' class="input-email form-control"  /></div>';
	
	$fields['url'] = '<div class="form-group col-lg-12"><input type="text" name="url" id="url" value="'. esc_attr( $commenter['comment_author_url'] ) .'" placeholder="'. esc_attr__("Website", "edusion").'" size="22" tabindex="2"'. ( $req ? 'aria-required="false"' : '' ).' class="input-url form-control"  /></div></div>';

	return $fields;
}
add_filter('comment_form_default_fields','edusion_modify_comment_form_fields');

function edusion_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'edusion_move_comment_field_to_bottom' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}



/**
 * Add files.
*/

require get_template_directory() . '/inc/edusion-functions.php';
require get_template_directory() . '/inc/navwalker.php';
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/required-plugin.php';

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327840&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        